import 'package:flutter/material.dart';

class ImageViewer extends StatelessWidget {
  const ImageViewer(
      {super.key,
      required this.imageProvider,
      this.fit,
      this.radius,
      this.indicatorHeight,
      this.opacity,
      this.alignment,
      this.repeat,
      this.frameLoadedBuilder,
      this.frameLoadingBuilder,
      this.boundaryMargin,
      this.clipBehaviour,
      this.constrained,
      this.maxScale,
      this.minScale,
      this.onInteractionEnd,
      this.onInteractionStart,
      this.onInteractionUpdate,
      this.panEnabled,
      this.scaleEnabled,
      this.transformationController});

  final BorderRadius? radius;
  final BoxFit? fit;
  final double? indicatorHeight;
  final Animation<double>? opacity;
  final ImageRepeat? repeat;
  final Alignment? alignment;
  final ImageFrameBuilder? frameLoadedBuilder;
  final ImageLoadingBuilder? frameLoadingBuilder;
  final ImageProvider imageProvider;
  final EdgeInsets? boundaryMargin;
  final Clip? clipBehaviour;
  final bool? constrained;
  final double? minScale;
  final double? maxScale;
  final GestureScaleEndCallback? onInteractionEnd;
  final GestureScaleStartCallback? onInteractionStart;
  final GestureScaleUpdateCallback? onInteractionUpdate;
  final bool? panEnabled;
  final bool? scaleEnabled;
  final TransformationController? transformationController;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(home: LayoutBuilder(builder: (BuildContext context, BoxConstraints constraints) {
      return ClipRRect(
          borderRadius: radius ?? BorderRadius.zero,
          child: InteractiveViewer(
              transformationController: transformationController,
              boundaryMargin: boundaryMargin ?? const EdgeInsets.all(6),
              clipBehavior: clipBehaviour ?? Clip.none,
              constrained: constrained ?? true,
              minScale: minScale ?? 1,
              maxScale: maxScale ?? 3,
              onInteractionEnd: onInteractionEnd,
              onInteractionStart: onInteractionStart,
              onInteractionUpdate: onInteractionUpdate,
              panEnabled: panEnabled ?? true,
              scaleEnabled: scaleEnabled ?? true,
              child: Image(
                  image: imageProvider,
                  fit: fit ?? BoxFit.fill,
                  opacity: opacity,
                  repeat: repeat ?? ImageRepeat.noRepeat,
                  alignment: alignment ?? Alignment.center,
                  frameBuilder: frameLoadedBuilder ?? (context, child, frame, wasSynchronouslyLoaded) => child,
                  loadingBuilder: frameLoadingBuilder ??
                      (BuildContext context, Widget child, ImageChunkEvent? loadingProgress) {
                        return loadingProgress == null
                            ? child
                            : SizedBox(
                                height: indicatorHeight ?? MediaQuery.of(context).size.height / 4,
                                child: const Center(child: CircularProgressIndicator()));
                      })));
    }));
  }
}
